"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EntityNotFoundError = void 0;
const EntitySchema_1 = require("../entity-schema/EntitySchema");
const TypeORMError_1 = require("./TypeORMError");
/**
 * Thrown when no result could be found in methods which are not allowed to return undefined or an empty set.
 */
class EntityNotFoundError extends TypeORMError_1.TypeORMError {
    constructor(entityClass, criteria) {
        super();
        this.message = `Could not find any entity of type "${this.stringifyTarget(entityClass)}" ` +
            `matching: ${this.stringifyCriteria(criteria)}`;
    }
    stringifyTarget(target) {
        if (target instanceof EntitySchema_1.EntitySchema) {
            return target.options.name;
        }
        else if (typeof target === "function") {
            return target.name;
        }
        else if (typeof target === "object" && "name" in target) {
            return target.name;
        }
        else {
            return target;
        }
    }
    stringifyCriteria(criteria) {
        try {
            return JSON.stringify(criteria, null, 4);
        }
        catch (e) { }
        return "" + criteria;
    }
}
exports.EntityNotFoundError = EntityNotFoundError;

//# sourceMappingURL=EntityNotFoundError.js.map
